SQLAlchemy 0.4 Documentation - module sqlalchemy.databases.oracle

# SQLAlchemy 0.4 Documentation

Multiple Pages | One Page
Version: 0.4.3 Last Updated: 02/14/08 18:54:07

### module sqlalchemy.databases.oracle

### Module Functions

def descriptor()

### class OracleBinary(Binary)

def bind_processor(self, dialect)
def get_col_spec(self)
def get_dbapi_type(self, dbapi)
def result_processor(self, dialect)
back to section top

### class OracleBoolean(Boolean)

def bind_processor(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class OracleChar(CHAR)

def get_col_spec(self)
back to section top

### class OracleCompiler(DefaultCompiler)

Oracle compiler modifies the lexical structure of Select statements to work under non-ANSI configured Oracle databases, if the use_ansi flag is False.

def __init__(self, *args, **kwargs)

Construct a new `OracleCompiler`.

def apply_function_parens(self, func)
def default_from(self)

Called when a `SELECT` statement has no froms, and no `FROM` clause is to be appended.

The Oracle compiler tacks a "FROM DUAL" to the statement.

def for_update_clause(self, select)
def get_whereclause(self, f)
def limit_clause(self, select)
def visit_alias(self, alias, asfrom=False, **kwargs)

Oracle doesn't like `FROM table AS alias`. Is the AS standard SQL??

def visit_join(self, join, **kwargs)
def visit_outer_join_column(self, vc)
def visit_select(self, select, **kwargs)

Look for `LIMIT` and OFFSET in a select statement, and if so tries to wrap it in a subquery with `row_number()` criterion.

def visit_sequence(self, seq)
back to section top

### class OracleDate(Date)

def bind_processor(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class OracleDateTime(DateTime)

def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class OracleDefaultRunner(DefaultRunner)

def visit_sequence(self, seq)
back to section top

### class OracleDialect(DefaultDialect)

def __init__(self, use_ansi=True, auto_setinputsizes=True, auto_convert_lobs=True, threaded=True, allow_twophase=True, **kwargs)

Construct a new `OracleDialect`.

def create_connect_args(self, url)
def create_execution_context(self, *args, **kwargs)
def create_xid(self)

create a two-phase transaction ID.

this id will be passed to do_begin_twophase(), do_rollback_twophase(), do_commit_twophase(). its format is unspecified.

def dbapi(cls)
def do_begin_twophase(self, connection, xid)
def do_commit_twophase(self, connection, xid, is_prepared=True, recover=False)
def do_prepare_twophase(self, connection, xid)
def do_recover_twophase(self, connection)
def do_release_savepoint(self, connection, name)
def do_rollback_twophase(self, connection, xid, is_prepared=True, recover=False)
def get_default_schema_name(self, connection)
def has_sequence(self, connection, sequence_name)
def has_table(self, connection, table_name, schema=None)
def is_disconnect(self, e)
def oid_column_name(self, column)
def reflecttable(self, connection, table, include_columns)
def table_names(self, connection, schema)
def type_descriptor(self, typeobj)
back to section top

### class OracleExecutionContext(DefaultExecutionContext)

def get_result_proxy(self)
def pre_exec(self)
back to section top

### class OracleIdentifierPreparer(IdentifierPreparer)

def format_savepoint(self, savepoint)
back to section top

### class OracleInteger(Integer)

def get_col_spec(self)
back to section top

### class OracleNumeric(Numeric)

def get_col_spec(self)
back to section top

### class OracleRaw(Binary)

def get_col_spec(self)
back to section top

### class OracleSchemaDropper(SchemaDropper)

def visit_sequence(self, sequence)
back to section top

### class OracleSchemaGenerator(SchemaGenerator)

def get_column_specification(self, column, **kwargs)
def visit_sequence(self, sequence)
back to section top

### class OracleSmallInteger(SmallInteger)

def get_col_spec(self)
back to section top

### class OracleString(String)

def get_col_spec(self)
back to section top

### class OracleText(Text)

def get_col_spec(self)
def get_dbapi_type(self, dbapi)
def result_processor(self, dialect)
back to section top

### class OracleTimestamp(TIMESTAMP)

def get_col_spec(self)
def get_dbapi_type(self, dialect)
def result_processor(self, dialect)
back to section top